==> apache-cxf-3.4.7-src.tar.gz: apache-cxf-3.4.7-src/rt/javascript/javascript-tests/src/test/java/org/apache/cxf/javascript/fortest/TestBean2.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.javascript.fortest;

import javax.xml.bind.annotation.XmlType;

/**
 * A second test class to test references.
 */
@XmlType(namespace = "uri:org.apache.cxf.javascript.testns3")
public class TestBean2 {

    public TestBean2() {
        stringItem = "testBean2.stringItem";
    }

    public TestBean2(String id) {
        stringItem = id;
    }

    @Override
    public String toString() {
        return "TestBean2 " + stringItem;
    }

    //CHECKSTYLE:OFF
    public String stringItem;
    //CHECKSTYLE:ON
    @Override
    public boolean equals(Object obj) {
        if (!(obj instanceof TestBean2)) {
            return false;
        }
        TestBean2 other = (TestBean2) obj;
        return stringItem.equals(other.stringItem);

    }

    @Override
    public int hashCode() {
        return stringItem.hashCode();
    }


}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/rt/javascript/javascript-tests/src/test/java/org/apache/cxf/javascript/fortest/TestBean2.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.javascript.fortest;

import jakarta.xml.bind.annotation.XmlType;

/**
 * A second test class to test references.
 */
@XmlType(namespace = "uri:org.apache.cxf.javascript.testns3")
public class TestBean2 {

    public TestBean2() {
        stringItem = "testBean2.stringItem";
    }

    public TestBean2(String id) {
        stringItem = id;
    }

    @Override
    public String toString() {
        return "TestBean2 " + stringItem;
    }

    //CHECKSTYLE:OFF
    public String stringItem;
    //CHECKSTYLE:ON
    @Override
    public boolean equals(Object obj) {
        if (!(obj instanceof TestBean2)) {
            return false;
        }
        TestBean2 other = (TestBean2) obj;
        return stringItem.equals(other.stringItem);

    }

    @Override
    public int hashCode() {
        return stringItem.hashCode();
    }


}
